==> App-MFILE-WWW-0.097.tar.gz: App-MFILE-WWW-0.097/share/js/core/tests/current-user.js <==
// ************************************************************************* 
// Copyright (c) 2014, SUSE LLC
// 
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
// 
// 1. Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
// 
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
// 
// 3. Neither the name of SUSE LLC nor the names of its contributors may be
// used to endorse or promote products derived from this software without
// specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.
// ************************************************************************* 
//
// tests/current-user.js
//
// Test the currentUser object
//
"use strict";

define ([
    'current-user'
], function (
    currentUser
) {

    return function () {
        test('currentUser object', function () {
            ok(currentUser.hasOwnProperty('obj'), "currentUser.obj OK");
            ok(currentUser.hasOwnProperty('priv'), "currentUser.priv OK");
            ok(currentUser.obj.hasOwnProperty('nick'), "currentUser.obj.nick OK");
            ok(currentUser.obj.hasOwnProperty('passhash'), "currentUser.obj.passhash OK");
            ok(currentUser.obj.hasOwnProperty('salt'), "currentUser.obj.salt OK");
        });
    };

});

==> App-MFILE-WWW-0.138.tar.gz: App-MFILE-WWW-0.138/share/js/core/tests/current-user.js <==
// ************************************************************************* 
// Copyright (c) 2014, SUSE LLC
// 
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
// 
// 1. Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
// 
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
// 
// 3. Neither the name of SUSE LLC nor the names of its contributors may be
// used to endorse or promote products derived from this software without
// specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.
// ************************************************************************* 
//
// tests/current-user.js
//
// Test the currentUser object
//
"use strict";

define ([
    'cf',
    'current-user'
], function (
    cf,
    currentUser
) {

    return function () {
        test('currentUser object', function () {

            // if 'connectToRestServer is false, the current-user object should be empty
            if (cf('connectToRestServer')) {
                ok(currentUser().hasOwnProperty('obj'), "currentUser.obj OK");
                ok(currentUser().hasOwnProperty('priv'), "currentUser.priv OK");
                ok(currentUser().obj.hasOwnProperty('nick'), "currentUser.obj.nick OK");
                ok(currentUser().obj.hasOwnProperty('passhash'), "currentUser.obj.passhash OK");
                ok(currentUser().obj.hasOwnProperty('salt'), "currentUser.obj.salt OK");
            } else {
                strictEqual(currentUser(), null, "connectToRestServer is false");
            }

        });
    };

});
